@@ -21,15 +21,24 @@
 #' @param df Data.frame
 #' @param sel Columns to be selected (Names or index or TRUE/FALSE vector).
 #'            DEFAULT: colnames(df)
+#' @param exclude_geometry Remove column with the name "geometry" 
+#'           (as in sf objects) from the display? DEFAULT: TRUE
+#' @param na.rm Exclude NA entries from the display? DEFAULT: FALSE
 #' 
 popleaf <- function(
 df,
-sel=colnames(df)
+sel=colnames(df),
+exclude_geometry=TRUE,
+na.rm=FALSE
 )
 {
+df <- as.data.frame(df) # otherwise the next line doesn't work for sf
 sel <- colnames(df[,sel, drop=FALSE])
+if(exclude_geometry) sel <- sel[sel!="geometry"]
 apply(df, MARGIN=1, function(x)
  {
+ nna <- if(na.rm) !is.na(x[sel]) else TRUE
+ sel <- sel[nna]
  paste(sel, ": ", x[sel], collapse="<br>")
  })
 }
